# AC-WEBSOCKETS-SERVER

The ac-websockets-server is a python based server to control a local Assetto Corsa dedicated server via a websockets connection from a remote host.

## Installation

You can install ac-websockets-server from PyPi:

```
pip install ac-websockets-server
```

The module is only supported in python3.

## How to use

TBA
